==> haskell-os-string-2.0.6-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-os-string.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 os-string
version:              2.0.6
visibility:           public
id:                   os-string-2.0.6-J05HN0oQxyEA3QBdwlGxW7
key:                  os-string-2.0.6-J05HN0oQxyEA3QBdwlGxW7
license:              BSD-3-Clause
copyright:            Julain Ospald 2021-2023
maintainer:           Julian Ospald <hasufell@posteo.de>
author:               Julian Ospald <hasufell@posteo.de>
homepage:             https://github.com/haskell/os-string/blob/master/README.md
synopsis:             Library for manipulating Operating system strings.
description:
    This package provides functionality for manipulating @OsString@ values, and is shipped with <https://www.haskell.org/ghc/ GHC>.

category:             System
abi:                  578199cfb145516d09e9c4fa89334eb4
exposed:              True
exposed-modules:
    System.OsString System.OsString.Data.ByteString.Short
    System.OsString.Data.ByteString.Short.Internal
    System.OsString.Data.ByteString.Short.Word16
    System.OsString.Encoding System.OsString.Encoding.Internal
    System.OsString.Internal System.OsString.Internal.Types
    System.OsString.Posix System.OsString.Windows

import-dirs:          /usr/lib/ghc-9.2.8/site-local/os-string-2.0.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/os-string-2.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-os-string
hs-libraries:         HSos-string-2.0.6-J05HN0oQxyEA3QBdwlGxW7
depends:
    base-4.16.4.0 bytestring-0.11.4.0 deepseq-1.4.6.1 exceptions-0.10.4
    template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-os-string/html/os-string.haddock
haddock-html:         /usr/share/doc/haskell-os-string/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-os-string-2.0.6-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-os-string.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 os-string
version:              2.0.6
visibility:           public
id:                   os-string-2.0.6-LJXPrHTF9HlJ3uluyab7ts
key:                  os-string-2.0.6-LJXPrHTF9HlJ3uluyab7ts
license:              BSD-3-Clause
copyright:            Julain Ospald 2021-2023
maintainer:           Julian Ospald <hasufell@posteo.de>
author:               Julian Ospald <hasufell@posteo.de>
homepage:             https://github.com/haskell/os-string/blob/master/README.md
synopsis:             Library for manipulating Operating system strings.
description:
    This package provides functionality for manipulating @OsString@ values, and is shipped with <https://www.haskell.org/ghc/ GHC>.

category:             System
abi:                  c32c88e4fd9e356caaf67e8b9a2f6b76
exposed:              True
exposed-modules:
    System.OsString System.OsString.Data.ByteString.Short
    System.OsString.Data.ByteString.Short.Internal
    System.OsString.Data.ByteString.Short.Word16
    System.OsString.Encoding System.OsString.Encoding.Internal
    System.OsString.Internal System.OsString.Internal.Types
    System.OsString.Posix System.OsString.Windows

import-dirs:          /usr/lib/ghc-9.2.8/site-local/os-string-2.0.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/os-string-2.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-os-string
hs-libraries:         HSos-string-2.0.6-LJXPrHTF9HlJ3uluyab7ts
depends:
    base-4.16.4.0 bytestring-0.11.4.0 deepseq-1.4.6.1 exceptions-0.10.4
    template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-os-string/html/os-string.haddock
haddock-html:         /usr/share/doc/haskell-os-string/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
